@@ -1,6 +1,6 @@
 package Mail::DMARC::Base;
 {
-  $Mail::DMARC::Base::VERSION = '0.20130524';
+  $Mail::DMARC::Base::VERSION = '0.20130528';
 }
 use strict;
 use warnings;
@@ -107,14 +107,25 @@ sub is_public_suffix {
 sub has_dns_rr {
     my ( $self, $type, $domain ) = @_;
 
-    my $matches = 0;
+    my @matches;
     my $res     = $self->get_resolver();
-    my $query   = $res->query( $domain, $type ) or return $matches;
+    my $query   = $res->query( $domain, $type ) or do {
+        return 0 if ! wantarray;
+        return @matches;
+    };
     for my $rr ( $query->answer ) {
         next if $rr->type ne $type;
-        $matches++;
+        push @matches, $rr->type eq  'A'   ? $rr->address
+                     : $rr->type eq 'PTR'  ? $rr->ptrdname
+                     : $rr->type eq  'NS'  ? $rr->nsdname
+                     : $rr->type eq  'TXT' ? $rr->txtdata
+                     : $rr->type eq  'SPF' ? $rr->txtdata
+                     : $rr->type eq 'AAAA' ? $rr->address
+                     : $rr->type eq  'MX'  ? $rr->exchange
+                     : $rr->answer;
     }
-    return $matches;
+    return scalar @matches if ! wantarray;
+    return @matches;
 }
 
 sub epoch_to_iso {
@@ -176,6 +187,11 @@ sub slurp {
     return $contents;
 }
 
+sub verbose {
+    return $_[0]->{verbose} if 1 == scalar @_;
+    return $_[0]->{verbose} = $_[1];
+};
+
 1;
 
 # ABSTRACT: DMARC utility functions
@@ -188,7 +204,7 @@ Mail::DMARC::Base - DMARC utility functions
 
 =head1 VERSION
 
-version 0.20130524
+version 0.20130528
 
 =head1 METHODS
 
