@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Aggregate;
 {
-  $Mail::DMARC::Report::Aggregate::VERSION = '0.20130524';
+  $Mail::DMARC::Report::Aggregate::VERSION = '0.20130528';
 }
 use strict;
 use warnings;
@@ -73,6 +73,7 @@ sub get_record_as_xml {
     my $rec_xml = " <record>\n";
     foreach my $row ( @{ $self->{record} } ) {
         my $ip = $row->{source_ip} or croak "no source IP!?";
+        $row->{policy_evaluated}{disposition} or croak "no disposition?";
         next if !defined $ips{$ip};    # already reported
         my $count = delete $ips{$ip};
         $rec_xml
@@ -146,6 +147,7 @@ sub get_policy_evaluated_as_xml {
     }
 
     foreach my $reason ( keys %$reasons ) {
+        next if ! $reason;
         $pe .= "    <reason>\n     <type>$reason</type>\n";
         $pe .= "     <comment>$reasons->{$reason}</comment>\n"
             if $reasons->{$reason};
@@ -160,7 +162,7 @@ sub get_policy_evaluated_as_xml {
 
 package Mail::DMARC::Report::Aggregate::Metadata;
 {
-  $Mail::DMARC::Report::Aggregate::Metadata::VERSION = '0.20130524';
+  $Mail::DMARC::Report::Aggregate::Metadata::VERSION = '0.20130528';
 }
 use strict;
 use warnings;
@@ -210,6 +212,7 @@ sub error {
 }
 
 sub domain {
+# this is where locally generated reports store the recipient domain
     return $_[0]->{domain} if 1 == scalar @_;
     return $_[0]->{domain} = $_[1];
 }
@@ -251,7 +254,7 @@ Mail::DMARC::Report::Aggregate - DMARC aggregate report
 
 =head1 VERSION
 
-version 0.20130524
+version 0.20130528
 
 =head1 DESCRIPTION
 
