@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::Send::SMTP;
 {
-  $Mail::DMARC::Report::Send::SMTP::VERSION = '0.20130524';
+  $Mail::DMARC::Report::Send::SMTP::VERSION = '0.20130528';
 }
 use strict;
 use warnings;
@@ -36,14 +36,6 @@ sub email {
         $args{to} = $original_to;
     }
     return $self->via_net_smtp( \%args );
-
-    #    eval { require MIME::Lite; }; ## no critic (Eval)
-    #    if ( !$EVAL_ERROR ) {
-    #        return 1 if $self->via_mime_lite( \%args );
-    #    }
-
-    #    carp "failed to send with MIME::Lite.";
-    #   croak "unable to send message";
 }
 
 sub via_net_smtp {
@@ -66,7 +58,7 @@ sub via_net_smtp {
     my $smtp = Net::SMTPS->new(
         [@try_mx],
         Timeout         => 10,
-        Port            => 25,
+        Port            => $c->{smarthost} ? 587 : 25,
         Hello           => $hostname,
         doSSL           => 'starttls',
         SSL_verify_mode => 'SSL_VERIFY_NONE',
@@ -132,14 +124,14 @@ sub get_smtp_hosts {
 }
 
 sub get_subject {
-    my ( $self, $args ) = @_;
+    my ( $self, $agg_ref ) = @_;
 
 
-    my $id = POSIX::strftime( "%Y.%m.%d.", localtime )
-        . ( $args->{report_id} || time );
+    my $rid = $$agg_ref->{metadata}{report_id} || time;
+    my $id = POSIX::strftime( "%Y.%m.%d.", localtime ) . $rid;
     my $us = $self->config->{organization}{domain};
-    return
-        "Report Domain: $args->{policy_domain} Submitter: $us Report-ID: <$id>";
+    my $pol_dom = $$agg_ref->{policy_published}{domain};
+    return "Report Domain: $pol_dom Submitter: $us Report-ID: <$id>";
 }
 
 sub get_filename {
@@ -154,14 +146,17 @@ sub get_filename {
         $self->config->{organization}{domain},
         $args->{policy_domain},
         $args->{begin}, $args->{end}, $args->{report_id} || time,
-    ) . '.xml.gz';
+    ) . '.xml';
 }
 
 sub _assemble_message {
     my ( $self, $args ) = @_;
 
     my $filename = $self->get_filename($args);
-    my $cf       = ( time > 1372662000 ) ? 'gzip' : 'zip';   # gz after 7/1/13
+#   my $cf       = ( time > 1372662000 ) ? 'gzip' : 'zip';   # gz after 7/1/13
+    my $cf       = 'gzip';
+      $filename .= $cf eq 'gzip' ? '.gz' : '.zip';
+
     my @parts    = Email::MIME->create(
         attributes => {
             content_type => "text/plain",
@@ -197,50 +192,10 @@ sub _assemble_message {
 }
 
 sub via_mail_sender {
-}
-
-sub via_mime_lite {
-    my $self = shift;
-    my $args = shift;
-
-    #warn "sending email with MIME::Lite\n";
-    my $message = MIME::Lite->new(
-        From    => $self->config->{organization}{email},
-        To      => $args->{to},
-        Subject => $args->{subject},
-        Type    => $args->{type} || 'multipart/alternative',
-    );
-
-    $message->attach( Type => 'TEXT', Data => $args->{body} ) or croak;
-    $message->attach( Type => 'application/gzip', Data => $args->{report} )
-        or croak;
-
-    my $smart_host = $args->{smart_host};
-    if ($smart_host) {
-
-        #warn "using smart_host $smart_host\n";
-        eval { $message->send( 'smtp', $smart_host, Timeout => 20 ) }; ## no critic (Eval)
-        if ( !$EVAL_ERROR ) {
-
-            #warn "sent using MIME::Lite and smart host $smart_host\n";
-            return 1;
-        }
-        carp "failed to send using MIME::Lite to $smart_host\n";
-    }
-
-    eval { $message->send('smtp'); };    ## no critic (Eval)
-    if ( !$EVAL_ERROR ) {
-        return 1;
-    }
-
-    eval { $message->send(); };          ## no critic (Eval)
-    if ( !$EVAL_ERROR ) {
-        return 1;
-    }
-
     return;
 }
 
+
 1;
 
 # ABSTRACT: send DMARC reports via SMTP
@@ -253,7 +208,7 @@ Mail::DMARC::Report::Send::SMTP - send DMARC reports via SMTP
 
 =head1 VERSION
 
-version 0.20130524
+version 0.20130528
 
 =head2 SUBJECT FIELD
 
