@@ -1,6 +1,6 @@
 package Mail::DMARC::Report::View::CLI;
 {
-  $Mail::DMARC::Report::View::CLI::VERSION = '0.20130524';
+  $Mail::DMARC::Report::View::CLI::VERSION = '0.20130528';
 }
 use strict;
 use warnings;
@@ -19,7 +19,7 @@ sub list {
     my $self    = shift;
     my $reports = $self->store->retrieve;
     foreach my $report ( reverse @$reports) {
-        printf "%3s  %20s  %20s  %15s\n", @$report{qw/ rid rcpt_domain from_domain begin /};
+        printf "%3s  %20s  %20s  %15s\n", @$report{qw/ rid from_domain rcpt_domain begin /};
     }
     return $reports;
 }
@@ -50,7 +50,7 @@ Mail::DMARC::Report::View::CLI - view locally stored DMARC reports
 
 =head1 VERSION
 
-version 0.20130524
+version 0.20130528
 
 =head1 AUTHORS
 
